package jp.hsj.junknews;

import java.io.*;
import java.util.*;
import java.text.*;
import javax.xml.*;
import javax.xml.parsers.*;

public class TextImporter {

  private String sourceTextFile = "";
  private String dateString     = "";

  public static void main(String[] args) {

    Junknews junknews = new Junknews();
    TextImporter ti = new TextImporter();
    ti.setDateString(args[0]);
    ti.setSourceTextFile(args[1]);
    junknews = ti.importFromTextFile();
    ti.writeTextFile(args[2], "<?xml version=\"1.0\" encoding=\"Shift_JIS\"?>\n" + junknews.makeTextDocument());
  }

  public Junknews importFromTextFile() {
    return this.importFromTextFile(this.getSourceTextFile());
  }
  public Junknews importFromTextFile(String filename) {
    Junknews junknews = new Junknews();
    junknews          = this.makeJunknews(readTextFile(filename));
    return junknews;
  }
  public Junknews importFromPlainString(String plaintext) {
    Junknews  junknews = new Junknews();
    String[]  lines    = plaintext.split(System.getProperty("line.separator"));
    ArrayList source   = new ArrayList(Arrays.asList(lines));
    junknews           = this.makeJunknews(source);
    return junknews;
  }

  public Junknews makeJunknews(ArrayList lineBuffer) {
    ListIterator iterator = null;
    Junknews junknews = new Junknews();
    if (lineBuffer.size() > 0) {
      String workBuffer = "";
      iterator = lineBuffer.listIterator();
      while (iterator.hasNext()) {
        
        News news = new News();
        Title title = new Title();
        Comment comment = new Comment();
        String titleString = "";
        String urlString = "";
        boolean existComment = false;
        String commentString = "";
        String genreString = "";
        
        // Blank
        while (iterator.hasNext()) {
          String thisLine = (String) iterator.next();
          if (thisLine.equals("") == false) {
            Object objDummy = iterator.previous();
            break;
          }
        }
        // GENRE
        while (iterator.hasNext()) {
          String thisLine = (String) iterator.next();
          if (thisLine != null
              && thisLine.startsWith("[")
              && thisLine.endsWith("]")) {
            genreString =
              thisLine.substring(1, thisLine.length() - 1);
            break;
          }
          else {
            genreString = "";
            Object objDummy = iterator.previous();
            break;
          }
        }
        // TITLE
        while (iterator.hasNext()) {
          String thisLine = (String) iterator.next();
          if (thisLine == null
              || thisLine.equals("")
              || thisLine.startsWith("http://")) {
            Object objDummy = iterator.previous();
            break;
          }
          titleString = titleString + thisLine;
        }
        // TITLE-HREF
        while (iterator.hasNext()) {
          String thisLine = (String) iterator.next();
          if (urlString.equals("")
              && thisLine.startsWith("http://") == false) {
            break;
          }
          else if (
            urlString.equals("") == false && thisLine.equals("")) {
            Object objDummy = iterator.previous();
            break;
          }
          urlString = urlString + thisLine;
        }
        // Blank
        while (iterator.hasNext()) {
          String thisLine = (String) iterator.next();
          if (thisLine.equals("") == false) {
            if (thisLine.startsWith(" ")
                || thisLine.startsWith("\t")) {
              existComment = true;
            }
            Object objDummy = iterator.previous();
            break;
          }
        }
        if (existComment) {
          while (iterator.hasNext()) {
            String thisLine = (String) iterator.next();
            if (thisLine.equals("")) {
              Object objDummy = iterator.previous();
              break;
            }
            Br br = new Br();
            comment.addContent(new RString(thisLine));
            comment.addContent(br);
            commentString = commentString + thisLine;
          }
        }
        
        title.setContent(titleString);
        title.setHref(urlString);
        news.setTitle(title);
        news.setGenre(genreString);
        news.setDate(this.getDateString());
        news.setComment(comment);
        junknews.addNews(news);
        junknews.setDate(this.getDateString());
      }
    }
    
    return junknews;
  }
  
  public ArrayList readTextFile(String fileName) {
    ArrayList lineBuffer = new ArrayList();
    
    try {
      // FileReaderIuWFNg̍쐬
      FileReader fr = new FileReader(fileName);
      // BufferedReaderIuWFNg̍쐬
      BufferedReader br = new BufferedReader(fr);
      // linee|
      String lineString = "";

      while ((lineString = br.readLine()) != null) {
        lineBuffer.add(lineString);
      }
      br.close();
      fr.close();
      
    }
    catch (Exception e) {
      System.out.println(e);
      e.printStackTrace();
    }
    return lineBuffer;
  }
  
  public void writeTextFile(String fileName, String value) {
    ArrayList lineBuffer = new ArrayList();
    
    try {
      // FileReaderIuWFNg̍쐬
      FileWriter fw = new FileWriter(fileName);
      // BufferedReaderIuWFNg̍쐬
      BufferedWriter bw = new BufferedWriter(fw);
      
      bw.write(value);
      bw.flush();
      
      bw.close();
      fw.close();
      
    }
    catch (Exception e) {
      System.out.println(e);
      e.printStackTrace();
    }
  }
  public String getSourceTextFile() {
    return sourceTextFile;
  }
  
  public void setSourceTextFile(String sourceTextFile) {
    this.sourceTextFile = sourceTextFile;
  }
  public String getDateString() {
    return dateString;
  }
  
  public void setDateString(String dateString) {
    this.dateString = dateString;
  }
  
}
